@@ -609,8 +609,14 @@ TEST_F(OpenMeshTutorials, extending_the_mesh_using_traits) {
   EXPECT_TRUE(ok) << "Cannot write mesh to file 'smoothed_extended_output.off'";
 }
 
+
 TEST_F(OpenMeshTutorials, deleting_geometry_elements) {
-  MyMeshWithStatus mesh;
+  Mesh mesh;
+
+  // the request has to be called before a vertex/face/edge can be deleted. it grants access to the status attribute
+  mesh.request_face_status();
+  mesh.request_edge_status();
+  mesh.request_vertex_status();
 
   // generate vertices
   MyMeshWithStatus::VertexHandle vhandle[8];
@@ -708,11 +714,13 @@ TEST_F(OpenMeshTutorials, deleting_geometry_elements) {
   EXPECT_FALSE(mesh.status(vhandle[2]).deleted()) << "vertex shouldn't be deleted";
   EXPECT_FALSE(mesh.status(vhandle[3]).deleted()) << "vertex shouldn't be deleted";
 
+
   mesh.delete_vertex(vhandle[0], false);
   mesh.delete_vertex(vhandle[1], false);
   mesh.delete_vertex(vhandle[2], false);
   mesh.delete_vertex(vhandle[3], false);
 
+
   EXPECT_TRUE(mesh.status(vhandle[0]).deleted()) << "vertex should be deleted";
   EXPECT_TRUE(mesh.status(vhandle[1]).deleted()) << "vertex should be deleted";
   EXPECT_TRUE(mesh.status(vhandle[2]).deleted()) << "vertex should be deleted";
@@ -728,6 +736,7 @@ TEST_F(OpenMeshTutorials, deleting_geometry_elements) {
   EXPECT_TRUE(ok) << "Cannot write mesh to file 'deleted_output.off'";
 }
 
+
 TEST_F(OpenMeshTutorials, storing_custom_properties) {
   MyMesh mesh;
 
@@ -792,4 +801,89 @@ TEST_F(OpenMeshTutorials, storing_custom_properties) {
   EXPECT_TRUE(fill_props(mesh, mprop_map, true)) << "property not filled correctly";
 }
 
+/*Testcase for code snippet from flipping edges in triangle meshes
+ * */
+TEST_F(OpenMeshTutorials, flipping_edges) {
+  Mesh mesh;
+  // Add some vertices
+  Mesh::VertexHandle vhandle[4];
+  vhandle[0] = mesh.add_vertex(MyMesh::Point(0, 0, 0));
+  vhandle[1] = mesh.add_vertex(MyMesh::Point(0, 1, 0));
+  vhandle[2] = mesh.add_vertex(MyMesh::Point(1, 1, 0));
+  vhandle[3] = mesh.add_vertex(MyMesh::Point(1, 0, 0));
+  // Add two faces
+  std::vector<Mesh::VertexHandle> face_vhandles;
+  face_vhandles.push_back(vhandle[2]);
+  face_vhandles.push_back(vhandle[1]);
+  face_vhandles.push_back(vhandle[0]);
+  mesh.add_face(face_vhandles);
+  face_vhandles.clear();
+  face_vhandles.push_back(vhandle[2]);
+  face_vhandles.push_back(vhandle[0]);
+  face_vhandles.push_back(vhandle[3]);
+  mesh.add_face(face_vhandles);
+  // Now the edge adjacent to the two faces connects
+  // vertex vhandle[0] and vhandle[2].
+  // Find this edge and then flip it
+  for(Mesh::EdgeIter it = mesh.edges_begin(); it != mesh.edges_end(); ++it) {
+    if(!mesh.is_boundary(*it)) {
+      // Flip edge
+      EXPECT_EQ(vhandle[2].idx(), mesh.to_vertex_handle(mesh.halfedge_handle(*it,0)).idx()) << "expected vertex handle 2!" ;
+      EXPECT_EQ(vhandle[0].idx(), mesh.to_vertex_handle(mesh.halfedge_handle(*it,1)).idx()) << "expected vertex handle 0!" ;
+      mesh.flip(*it);
+      EXPECT_EQ(vhandle[1].idx(), mesh.to_vertex_handle(mesh.halfedge_handle(*it,0)).idx()) << "expected vertex handle 1 (did the flip work?)!" ;
+      EXPECT_EQ(vhandle[3].idx(), mesh.to_vertex_handle(mesh.halfedge_handle(*it,1)).idx()) << "expected vertex handle 3 (did the flip work?)!" ;
+    }
+  }
+  // The edge now connects vertex vhandle[1] and vhandle[3].
+}
+
+/*Testcase for code snippet from collapsing edges in triangle meshes
+ * */
+TEST_F(OpenMeshTutorials, collapsing_edges) {
+  PolyMesh mesh;
+  mesh.request_vertex_status();
+  mesh.request_edge_status();
+  // Add some vertices as in the illustration above
+  PolyMesh::VertexHandle vhandle[7];
+  vhandle[0] = mesh.add_vertex(MyMesh::Point(-1, 1, 0));
+  vhandle[1] = mesh.add_vertex(MyMesh::Point(-1, 3, 0));
+  vhandle[2] = mesh.add_vertex(MyMesh::Point(0, 0, 0));
+  vhandle[3] = mesh.add_vertex(MyMesh::Point(0, 2, 0));
+  vhandle[4] = mesh.add_vertex(MyMesh::Point(0, 4, 0));
+  vhandle[5] = mesh.add_vertex(MyMesh::Point(1, 1, 0));
+  vhandle[6] = mesh.add_vertex(MyMesh::Point(1, 3, 0));
+  // Add three quad faces
+  std::vector<PolyMesh::VertexHandle> face_vhandles;
+  face_vhandles.push_back(vhandle[1]);
+  face_vhandles.push_back(vhandle[0]);
+  face_vhandles.push_back(vhandle[2]);
+  face_vhandles.push_back(vhandle[3]);
+  mesh.add_face(face_vhandles);
+  face_vhandles.clear();
+  face_vhandles.push_back(vhandle[1]);
+  face_vhandles.push_back(vhandle[3]);
+  face_vhandles.push_back(vhandle[5]);
+  face_vhandles.push_back(vhandle[4]);
+  mesh.add_face(face_vhandles);
+  face_vhandles.clear();
+  face_vhandles.push_back(vhandle[3]);
+  face_vhandles.push_back(vhandle[2]);
+  face_vhandles.push_back(vhandle[6]);
+  face_vhandles.push_back(vhandle[5]);
+  mesh.add_face(face_vhandles);
+  // Now find the edge between vertex vhandle[2]
+  // and vhandle[3]
+  for(PolyMesh::HalfedgeIter it = mesh.halfedges_begin(); it != mesh.halfedges_end(); ++it) {
+    if( mesh.to_vertex_handle(*it) == vhandle[3] &&
+        mesh.from_vertex_handle(*it) == vhandle[2])
+    {
+      // Collapse edge
+      mesh.collapse(*it);
+      break;
+    }
+  }
+  // Our mesh now looks like in the illustration above after the collapsing.
+}
+
 }
